# TI-Status2Mattermost

Ein Python-Skript, das den TI-Status überwacht und neue Meldungen über Apprise an verschiedene Dienste sendet.

## Features

- Überwacht die TI-Status-API auf neue Meldungen
- Sendet Benachrichtigungen über Apprise (unterstützt viele Dienste wie Mattermost, Slack, Telegram, Discord, etc.)
- Konfiguration über .env Datei
- Markdown-Formatierung der Nachrichten
- Vermeidet Duplikate durch lokale Statusverfolgung
- Debug-Ausgaben für bessere Transparenz

## Installation

1. Repository klonen:
```bash
git clone <repository-url>
cd TI-Status2Mattermost
```

2. Virtuelle Umgebung erstellen und aktivieren:
```bash
python -m venv .venv
# Windows:
.venv\Scripts\activate
# Linux/Mac:
source .venv/bin/activate
```

3. Abhängigkeiten installieren:
```bash
pip install -r requirements.txt
```

## Konfiguration

1. Kopiere die Beispiel-Konfiguration:
```bash
cp env.example .env
```

2. Bearbeite die `.env` Datei und setze deine Apprise URL:

### Mattermost Webhook
```
APPRISE_URL=mattermost://username:password@mattermost.medisoftware.org/channel?webhook=your_webhook_id
```

### Andere Dienste
- **Slack**: `APPRISE_URL=slack://token_a/token_b/token_c/#channel`
- **Telegram**: `APPRISE_URL=telegram://bottoken/ChatID`
- **Discord**: `APPRISE_URL=discord://webhook_id`

Weitere Apprise-URLs findest du in der [Apprise-Dokumentation](https://github.com/caronc/apprise#supported-notifications).

## Verwendung

Skript einmalig ausführen:
```bash
python ti_status_checker.py
```

Das Skript gibt Debug-Informationen aus:
- API-Aufruf und Antwort
- Anzahl der gefundenen Meldungen
- Verarbeitung jeder einzelnen Meldung

Für kontinuierliche Überwachung (z.B. mit cron):
```bash
# Alle 5 Minuten ausführen
*/5 * * * * cd /path/to/TI-Status2Mattermost && python ti_status_checker.py
```

## Unterstützte Dienste

Apprise unterstützt über 80 verschiedene Benachrichtigungsdienste, darunter:
- Mattermost
- Slack
- Telegram
- Discord
- Email
- Pushover
- Microsoft Teams
- und viele weitere

## Dateien

- `ti_status_checker.py` - Hauptskript mit Debug-Ausgaben
- `requirements.txt` - Python-Abhängigkeiten (python-dotenv, apprise)
- `env.example` - Beispiel-Konfiguration
- `ti_status_state.json` - Lokale Statusverfolgung (wird automatisch erstellt)
- `.env` - Deine Konfiguration (nicht im Repository)

## Changelog

### Version 2.0 (Apprise-Integration)
- ✅ Umstellung von Mattermost Webhook auf Apprise API
- ✅ Konfiguration über .env Datei
- ✅ Unterstützung für über 80 Benachrichtigungsdienste
- ✅ Debug-Ausgaben für bessere Transparenz
- ✅ Verbesserte Markdown-Formatierung

### Version 1.0 (Ursprünglich)
- Mattermost Webhook Integration
- Lokale Statusverfolgung

## Lizenz

[Deine Lizenz hier] 